@@ -57,7 +57,7 @@ class Tron : public QWidget
 	Q_OBJECT
 
 	public:
-		Tron(QWidget *parent=0);
+        explicit Tron(QWidget *parent=nullptr);
 		~Tron();
 		void updatePixmap();
 		void setVelocity(int);
@@ -70,7 +70,7 @@ class Tron : public QWidget
 		bool hasWinner();
 		int getWinner();
 
-	public slots:
+	public Q_SLOTS:
 		/** Starts a new game. The difference to reset is, that the players
 		* points are set to zero. Emits gameEnds(Nobody).
 		*/
@@ -79,7 +79,7 @@ class Tron : public QWidget
 		void loadSettings();
 		void itemHit(int playerNumber, int x, int y);
 
-	signals:
+	Q_SIGNALS:
 		void gameEnds();
 		void updatedScore();
 		void gameReset();
@@ -141,18 +141,18 @@ class Tron : public QWidget
 		// Key handling / movement
 		void switchKeyOn(int, KBAction::Action);
 		void switchKeyOff(int, KBAction::Action);
-		/** Check head to head collissions */
-		void checkHeadToHeadCollission();
+		/** Check head to head collisions */
+		void checkHeadToHeadCollision();
 		/** Helper for the doMove() function */
 		void movementHelper(bool onlyAcceleratedPlayers);
 		/** Tries to generate a new obstacle */
 		void newObstacle();
 	
-	private slots:
+	private Q_SLOTS:
 		/**
 		* This is the main function of KTron.
-		* It checkes if an accelerator is pressed and than moves this player
-		* forward. Then it checkes if a crash occurred.
+		* It checks if an accelerator is pressed and than moves this player
+		* forward. Then it checks if a crash occurred.
 		* If no crash happen it moves both players forward and checks again
 		* if someone crashed.
 		*/
